@@ -2,13 +2,23 @@ package Sereal;
 use 5.008;
 use strict;
 use warnings;
-our $VERSION = '4.001_003';
+our $VERSION = '4.007_001';
 our $XS_VERSION = $VERSION; $VERSION= eval $VERSION;
-use Sereal::Encoder 4.001_003 qw(encode_sereal sereal_encode_with_object);
-use Sereal::Decoder 4.001_003 qw(
-    decode_sereal looks_like_sereal decode_sereal_with_header_data
+use Sereal::Encoder 4.007_001 qw(
+    encode_sereal
+    sereal_encode_with_object
+    SRL_UNCOMPRESSED
+    SRL_SNAPPY
+    SRL_ZLIB
+    SRL_ZSTD
+);
+use Sereal::Decoder 4.007_001 qw(
+    decode_sereal
+    looks_like_sereal
+    decode_sereal_with_header_data
     scalar_looks_like_sereal
-    sereal_decode_with_object sereal_decode_with_header_with_object
+    sereal_decode_with_object
+    sereal_decode_with_header_with_object
     sereal_decode_only_header_with_object
     sereal_decode_only_header_with_offset_with_object
     sereal_decode_with_header_and_offset_with_object
@@ -17,22 +27,35 @@ use Sereal::Decoder 4.001_003 qw(
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
-  get_sereal_decoder
-  get_sereal_encoder
-  clear_sereal_object_cache
+    get_sereal_decoder
+    get_sereal_encoder
+    clear_sereal_object_cache
 
-  encode_sereal decode_sereal
-  write_sereal read_sereal
-  looks_like_sereal
-  sereal_encode_with_object
-  sereal_decode_with_object
-  decode_sereal_with_header_data
-  scalar_looks_like_sereal
-  sereal_decode_with_header_with_object
-  sereal_decode_only_header_with_object
-  sereal_decode_only_header_with_offset_with_object
-  sereal_decode_with_header_and_offset_with_object
-  sereal_decode_with_offset_with_object
+    encode_sereal
+    decode_sereal
+
+    read_sereal
+    read_sereal_file
+    write_sereal
+    write_sereal_file
+
+    looks_like_sereal
+    scalar_looks_like_sereal
+
+    sereal_encode_with_object
+    sereal_decode_with_object
+    decode_sereal_with_header_data
+
+    sereal_decode_with_header_with_object
+    sereal_decode_only_header_with_object
+    sereal_decode_only_header_with_offset_with_object
+    sereal_decode_with_header_and_offset_with_object
+    sereal_decode_with_offset_with_object
+
+    SRL_UNCOMPRESSED
+    SRL_SNAPPY
+    SRL_ZLIB
+    SRL_ZSTD
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 # export by default if run from command line
@@ -44,8 +67,10 @@ our %DECODERS;
 sub _key { join "\t", map { $_ => $_[0]->{$_} } sort keys %{$_[0]} }
 
 sub clear_sereal_object_cache {
+    my $count= keys(%DECODERS) + keys(%ENCODERS);
     %ENCODERS= ();
     %DECODERS= ();
+    return $count;
 }
 
 sub get_sereal_encoder {
@@ -58,16 +83,21 @@ sub get_sereal_decoder {
     return $DECODERS{_key($opts)} ||= Sereal::Decoder->new($opts);
 }
 
-sub write_sereal {
+sub write_sereal_file {
     my ($file, $struct, $append, $opts)= @_;
-    get_sereal_encoder($opts)->write_to_file($file, $_[1], $append);
+    get_sereal_encoder($opts)->encode_to_file($file, $_[1], $append);
 }
 
-sub read_sereal {
+sub read_sereal_file {
     my ($file, $opts)= @_;
-    get_sereal_decoder($opts)->read_from_file($file,$_[2]);
+    get_sereal_decoder($opts)->decode_from_file($file,@_ > 2 ? $_[2] : ());
 }
 
+*read_sereal= *read_sereal= *read_sereal_file;
+*write_sereal= *write_sereal= *write_sereal_file;
+
+
+
 1;
 
 __END__
@@ -80,14 +110,41 @@ Sereal - Fast, compact, powerful binary (de-)serialization
 
 =head1 SYNOPSIS
 
-  use Sereal qw(encode_sereal decode_sereal
-                sereal_encode_with_object
-                sereal_decode_with_object
-                looks_like_sereal);
-  # Note: For performance reasons, you should prefer the OO interface,
-  #       or sereal_(en|de)code_with_object over the stateless
-  #       encode_sereal/decode_sereal functions.
-  #       See the Sereal::Performance documentation for details.
+    use Sereal qw(
+        get_sereal_decoder
+        get_sereal_encoder
+        clear_sereal_object_cache
+
+        encode_sereal
+        decode_sereal
+
+        read_sereal
+        read_sereal_file
+        write_sereal
+        write_sereal_file
+
+        looks_like_sereal
+        scalar_looks_like_sereal
+
+        sereal_encode_with_object
+        sereal_decode_with_object
+        decode_sereal_with_header_data
+
+        sereal_decode_with_header_with_object
+        sereal_decode_only_header_with_object
+        sereal_decode_only_header_with_offset_with_object
+        sereal_decode_with_header_and_offset_with_object
+        sereal_decode_with_offset_with_object
+
+        SRL_UNCOMPRESSED
+        SRL_SNAPPY
+        SRL_ZLIB
+        SRL_ZSTD
+    );
+    # Note: For performance reasons, you should prefer the OO interface,
+    #       or sereal_(en|de)code_with_object over the stateless
+    #       encode_sereal/decode_sereal functions.
+    #       See the Sereal::Performance documentation for details.
 
 =head1 DESCRIPTION
 
@@ -132,6 +189,37 @@ After loading the C<Sereal> module, both C<Sereal::Encoder> and
 C<Sereal::Decoder> are guaranteed to be loaded, so you can use
 their object-oriented interface.
 
+=head2 get_sereal_encoder($OPTSHASH)
+
+Returns a Sereal::Encoder with the given options. This encoder will be shared by other calls
+to this function.
+
+=head2 get_sereal_decoder($OPTSHASH)
+
+Returns a Sereal::Decoder with the given options. This encoder will be shared by other calls
+to this function.
+
+=head2 clear_sereal_object_cache
+
+Clears cache of objects created via get_sereal_encoder() and get_sereal_decoder(). Returns
+the number of objects that were removed from the cache (the sum of both types).
+
+=head2 write_sereal_file($FILENAME,$STRUCT,$APPEND,$OPTS)
+
+Write a sereal packet to $FILENAME. See Sereal::Encoder::encode_to_file().
+
+=head2 write_sereal($FILENAME,$STRUCT,$APPEND,$OPTS)
+
+alias for write_sereal_file()
+
+=head2 read_sereal_file($FILENAME,$OPTS,$ROOT)
+
+Read a sereal packet from a file. See Sereal::Decoder::decode_from_file().
+
+=head2 read_sereal($FILENAME,$OPTS,$ROOT)
+
+alias for read_sereal_file()
+
 =head1 BUGS, CONTACT AND SUPPORT
 
 For reporting bugs, please use the github bug tracker at
